@@ -56,7 +56,8 @@ class EnrichConfigTest(TestCase):
 
     def test_not_given__auto_detection(self):
         config = parse_command_line(['gentoo-tree-diff', 'dir1', 'dir2'])
-        with patch('subprocess.check_output', self._fake_subprocess_check_output):
+        with patch('subprocess.check_output', self._fake_subprocess_check_output), \
+                patch('sys.stdout', StringIO()):
             enrich_config(config)
         self.assertEqual(config.keywords, {'one', 'two', '~*'})
 
@@ -95,8 +96,6 @@ class IterateNewAndChangedEbuildsTest(TestCase):
             if extra_content is not None:
                 print(extra_content, file=f)
             f.flush()
-        with open(filename) as f:
-            print('CONTENT', f.read())
 
     def test_new_live_ebuild_ignored_by_filename(self):
         keywords = 'one'
